Introduction — Documentation audiometry_trainer 0.1.16

# Introduction

`audiometry_trainer` est un logiciel pour s’entraîner à l’audiométrie clinique. Le logiciel simule les réponses de patients depuis des fichiers de cas et permet de pratiquer des aspects essentiels de la procédure, y compris la recherche de seuil par voie aérienne/osseuse et le masquage clinique. La figure Capture d’écran de la fenêtre principale de audiometry_trainer affiche la fenêtre principale de `audiometry_trainer`. Des tutoriels vidéo sont disponible sur Youtube.

Fig. 1 Capture d’écran de la fenêtre principale de `audiometry_trainer`

Au démarrage `audiometry_trainer` sélectionne de façon aléatoire un fichier de cas de patient virtuel (vous pouvez charger d’autres cas depuis le menu `Fichier`).

Fig. 2 Fichier menu

Le marqueur `S` affiché dans la fenêtre de l’audiogramme indique la fréquence et le niveau courants du stimulus. C’est plus pratique d’effectuer la recherche du seuil avec le clavier qu’en cliquant sur des boutons avec la souris. Appuyez sur la barre d’espace pour jouer le stimulus (le `Témoin du stimulus` en bas s’allumera). Si le patient virtuel a entendu le son le `Témoin de réponse` sur la gauche s’allumera. Utilisez les flèches haut/bas du clavier pour changer le niveau du stimulus. Lorsque vous avez trouvé le seuil, marquez-le en appuyant sur la touche `T` (de l’anglais « Threshold »). Utilisez les flèches droite/gauche du clavier pour vous déplacer sur une autre fréquence.

Vous pouvez comparer les seuils que vous avez mesuré avec les seuils attendus en cochant les cases sous `Affichage des vrais seuils` dans la partie basse du panneau de gauche. Les patients virtuels sont modelés à travers des courbes psychométriques et les « vrais » seuils sont calculés à travers des méthodes de Monte-Carlo : ils sont les seuils médians obtenus sur un large nombre de simulations ; des intervalles de confiance de 95% peuvent être affichés en cochant les cases `CI`.

Vous pouvez passer de l’oreille droite à la gauche et de la stimulation en conduction aérienne à celle en conduction osseuse en sélectionnant les options souhaitées dans les menus déroulant pour le `Canal 1` en haut du panneau de gauche. Le `Canal 2` est utilisé pour envoyer du bruit masquant. Pour allumer le `Canal 2` cochez la case `Can. 2 ON` sur le panneau de droite, un marqueur `M` dans la fenêtre de l’audiogramme affichera le niveau courant du bruit masquant. Vous pouvez utiliser la case `Niveau du can. 2` ainsi que les flèches haut/bas à sa droite pour saisir le niveau du bruit masquant. Vous pouvez aussi « verrouiller » le `Canal 2` au `Canal 1` en cochant la case `Verrouiller les canaux` sur le panneau de droite : lorsque les canaux sont verrouillés, des augmentations/baisses du niveau du stimulus d’une taille donné déclencheront automatiquement des changements du niveau du masqueur de la même taille.

Une description détaillée de toutes les fonctionnalités de `audiometry_trainer` sera donne dans les sections suivantes. La Section Installation explique comment obtenir et installer `audiometry_trainer`. Les sections Recherche du seuil and Masquage expliquent comment faire une recherche de seuil et comment utiliser le masquage, respectivement.

`audiometry_trainer` utilise des courbes psychométriques pour modéliser les réponses des patients virtuels. Les réponses ne sont pas déterministes (toujours oui/non au dessus/dessous d’un certain niveau de stimulation) mais probabilistes, avec une probabilité de réponse croissante en fonction du niveau de stimulation. Cela rends le logiciel plus réaliste car dans la vie réelle les réponses des patients ne sont pas déterministes. La section Sujet virtuel détaille le modèle de courbe psychométrique utilisé par `audiometry_trainer`.

`audiometry_trainer` vous permet de générer et utiliser vous propres fichiers de cas. Vous pouvez accéder à cette fonctionnalité à travers l’action `Générer un cas` sous le menu `Fichier` et ça sera illustré en détails dans la Section Générer des fichiers de cas. Quelques connaissances du modèle de fonction psychométrique utilisé par `audiometry_trainer` seront nécessaires pour la création de vos propres fichiers de cas.

La Section Interface utilisateur couvre en détail toute l’interface utilisateur. La Section Fonctionnement interne décrits quelques aspects du fonctionnement interne du logiciel et est adressée aux développeurs plutôt qu’aux utilisateurs du logiciel.